@@ -78,7 +78,7 @@ create_app <- function(app_name,
   # Create app config file
   create_config(app_name, R_version, app_dir, pkgs, remotes = dots$remotes,
     repo = dots$repo, error_log = dots$error_log, app_repo_url = dots$app_repo_url,
-    auth_user = dots$auth_user, auth_pw = dots$auth_pw)
+    auth_user = dots$auth_user, auth_pw = dots$auth_pw, user_browser = dots$user_browser)
 
   # Build the iss script
   iss <- start_iss(app_name)
